<?php

namespace Drupal\entity_reference_layout;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

class EntityReferenceLayoutSettingsForm extends ConfigFormBase {

  /**
   * Config settings.
   *
   * @var string
   */
  const SETTINGS = 'entity_reference_layout.settings';

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'entity_reference_layout_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      static::SETTINGS,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config(static::SETTINGS);

    $form['show_paragraph_labels'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Show Paragraph Labels'),
      '#default_value' => $config->get('show_paragraph_labels'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $settings = $this->config(static::SETTINGS);
    foreach ($values as $key => $value) {
      $settings->set($key, $value);
    }
    $settings->save();
    parent::submitForm($form, $form_state);
  }

}
